require 'settings'
require 'controllers/menu_controller'
require 'controllers/game_controller'
require 'controllers/editor_controller'
require 'player'
require 'fadeover_effects/crossfade_effect'
require 'fadeover_effects/slide_out_effect'
require 'fadeover_effects/flash_fade_effect'

class LevelselectionMenuController < MenuController
  def initialize(players = [])
    super()
    
    @controls = Settings.controls
    
    @potential_players = players
    if @potential_players.size == 0
      @controls.each_with_index do |ctrl, i|
        @potential_players.push Player.new(i, i + 1, ctrl)
      end
    end
    @players = []
    
    @levels = Level.load_all
    
    @menu_items = @levels.map do |l|
      {
        :title                 => l.name,
        :on_select             => lambda { finish! GameController.new(l, @players, @potential_players), CrossfadeEffect.new(500) if @players.size > 0 },
        :on_select_alternative => lambda { l.editing = true; finish! EditorController.new(l) }
      }
    end + [{
      :title     => "Level Editor",
      :on_select => lambda { finish! EditorController.new }
    }]
  end
  
  def handle_event(event)
    super event
    
    finish!(MainMenuController.new) if @keys.include?(:escape)
    
    @potential_players.each do |player|
      if @keys.include?(player.keys[:plant_bomb])
        @players.push(player) unless @players.include?(player)
      end
    end
  end
  
  def draw(srf)
    srf.fill [50, 50, 0]
    
    if @levels.size > @selected_item
      preview = Rubygame::Surface.new [@levels[@selected_item].width, @levels[@selected_item].height]
      @levels[@selected_item].draw preview, V(0, 0)
      preview = preview.zoom(0.8, true)
      preview.alpha = 50
      preview.blit srf, [50, 50]
    end
    
    @potential_players.each_with_index do |player, i|
      player.draw_selection_menu srf, V(Game.screen.width - 250, player.number * 180), @players.include?(player)
    end
    
    super
  end
  
  def finish!(next_controller = nil, fadeover_effect = nil)
    super next_controller, fadeover_effect || CrossfadeEffect.new
  end
end
