require 'game_object'

class Field < GameObject
  attr_accessor :rect, :items, :coords
  
  def initialize(position, rect, coords)
    @rect = rect
    @coords = coords
    @items = []
    super position, nil
  end
    
  def can_plant_bomb?
    r = true
    @items.each { |item| r = false unless item.can_plant_bomb? }
    r
  end
  
  def walkable?
    r = true
    @items.each { |i| r = false unless i.walkable? }
    r
  end
  def blowable?
    r = true
    @items.each { |i| r = false unless i.blowable? }
    r
  end
  def blocks_explosion?
    r = false
    @items.each { |i| r = true if i.blocks_explosion? }
    r
  end
  
  def blown(explosion)
    @items.each { |i| i.blown(explosion) }
  end
  def walked_over(player)
    @items.each { |i| i.walked_over(player) }
  end
  
  def draw(srf, offset)
    @items.each { |item| item.draw(srf, offset) }
  end
  
  def update(dtime)
    @items.each { |item| item.update(dtime) }
  end
  
  def distance_from_center(pos)
    (@pos - pos).abs
  end
  
  def get_item_chars
    if items.size > 0
      items.map do |item|
        case item.class.to_s
          when "Wall"
            'w'
          when "BlowableWall"
            'b'
        end
      end.join
    else
      'n'
    end
  end
end
