require 'controllers/main_menu_controller'
require 'timer'

class Game
  def self.setup
    Rubygame::Music.autoload_dirs = ["music"]
    Rubygame::Sound.autoload_dirs = ["sfx"]
    Rubygame::Surface.autoload_dirs = ["gfx"]
    
    @@screen = Rubygame::Screen.new [1000, 760], 0, [Rubygame::HWSURFACE, Rubygame::DOUBLEBUF]
    @@screen.title = "Bomberman"
    
    @@queue = Rubygame::EventQueue.new
    @@queue.enable_new_style_events
    
    @@clock = Rubygame::Clock.new
    @@clock.target_framerate = 60
    @@clock.calibrate
    
    @@current_controller = MainMenuController.new
    Rubygame::Music['menu.wav'].play :fade_in => 0.1, :repeats => -1, :start_at => 0
  end
  
  def self.run!
    Rubygame::TTF.setup
    Timer.setup
    
    until @@current_controller.nil? do
      Game.current_controller = @@current_controller
      until @@current_controller.is_finished do
        draw
        @@screen.flip
        update
      end
      @@current_controller = @@current_controller.next_controller
    end
    
    Timer.print_all
  end
  
  def self.update
    @@queue.each do |event|
      case event
        when Rubygame::Events::QuitRequested
          Rubygame.quit
          exit
      end
      
      @@current_controller.handle_event(event)
    end
    
    dtime = @@clock.tick
    @@current_controller.update(dtime)
    @@fadeover_effect.update(dtime) if @@fadeover_effect
  end
  
  def self.draw
    @@current_controller.draw(@@screen)
    @@fadeover_effect.draw(@@screen) if @@fadeover_effect
  end
  
  
  # Global stuff
  
  def self.screen
    @@screen
  end
  
  def self.current_controller
    @@current_controller
  end
  def self.current_controller=(controller)
    @@current_controller = controller
  end
  
  @@current_level = nil
  def self.current_level
    @@current_level
  end
  def self.current_level=(level)
    @@current_level = level
  end
  
  @@fadeover_effect = nil
  def self.fadeover_effect
    @@fadeover_effect
  end
  def self.fadeover_effect=(effect)
    @@fadeover_effect = effect
  end
  
  @@life_sprite = nil
  def self.life_sprite
    @@life_sprite ||= Sprite.new("life.png")
  end
  
  @@bomb_sprite = nil
  def self.bomb_sprite
    @@bomb_sprite ||= Sprite.new("bomb.png")
  end
  
  @@explosion_sprite = nil
  def self.explosion_sprite
    @@explosion_sprite ||= Sprite.new("explosion.png")
  end
  
  @@font = nil
  def self.font
    @@font ||= Rubygame::TTF.new("gfx/old-press.ttf", 30)
  end
end
