require 'items/item'
require 'sprite'

class Bomb < Item
  attr_accessor :player, :countdown
  
  def initialize(field, player)
    @player = player
    @countdown = Settings.gameplay.bomb_time
    
    @sprite = Sprite.new("bomb.png", {
      :lit0 => { :row => 0, :frames => 2, :framerate => 0.008 },
      :lit1 => { :row => 1, :frames => 2, :framerate => 0.008 },
      :lit2 => { :row => 2, :frames => 2, :framerate => 0.008 },
      :lit3 => { :row => 3, :frames => 2, :framerate => 0.008 }
    })
    @sprite.current_animation = :lit1
    
    super field, @sprite
    player.bombs += [self]
  end
  
  def update(dtime)
    super dtime
    
    @countdown -= dtime
    
    # choose sprite animation
    bomb_time = Settings.gameplay.bomb_time
    if @countdown > bomb_time/4*3
      @sprite.current_animation = :lit0
    elsif @countdown > bomb_time/4*2
      @sprite.current_animation = :lit1
    elsif @countdown > bomb_time/4*1
      @sprite.current_animation = :lit2
    else
      @sprite.current_animation = :lit3
    end
    
    explode! if @countdown <= 0
  end
  
  def walkable?
    false
  end
  def blowable?
    true
  end
  def blocks_explosion?
    false
  end
  def can_plant_bomb?
    false
  end
  
  def explode!
    @field.items  -= [self]
    @player.bombs -= [self]
    Game.current_level.create_explosion(@field, @player)
    Rubygame::Sound["blow.wav"].play
  end
  
  def blown(explosion)
    explode!
  end
end
